@@ -3,7 +3,7 @@
 #
 # This script generates from driver files fake C sources to be passed
 # through a C preprocessor to get the actual Java sources. It expects
-# as arguments the name of the driver and the name of the file to be 
+# as arguments the name of the driver and the name of the file to be
 # generated.
 #
 
@@ -31,6 +31,9 @@ TYPE_LC2=(boolean byte short int long char float double object object)
 # The corresponding classes (in few cases, there are differences with $TYPE_CAP).
 CLASS=(Boolean Byte Short Integer Long Character Float Double Object Reference)
 
+# The capitalized widened type (needed for interaction with some JDK primitive operators)
+WIDENED_TYPE_CAP=(Boolean Int Int Int Long Int Double Double Object Reference)
+
 export LC_ALL=C
 shopt -s extglob
 
@@ -64,14 +67,22 @@ else
 fi
 
 for((k=0; k<${#TYPE_CAP[*]}; k++)); do
-    if [[ ${TYPE_CAP[$k]} == $KEY_TYPE_CAP ]]; then break; fi;
+    if [[ ${TYPE_CAP[$k]} == ${KEY_TYPE_CAP} ]]; then break; fi;
 done
 
 for((v=0; v<${#TYPE_CAP[*]}; v++)); do
-    if [[ ${TYPE_CAP[$v]} == $VALUE_TYPE_CAP ]]; then break; fi;
+    if [[ ${TYPE_CAP[$v]} == ${VALUE_TYPE_CAP} ]]; then break; fi;
 done
 
-if [[ $root == *Linked* ]]; then 
+for((wk=0; wk<${#TYPE_CAP[*]}; wk++)); do
+    if [[ ${TYPE_CAP[$wk]} == ${WIDENED_TYPE_CAP[$k]} ]]; then break; fi;
+done
+
+for((wv=0; wv<${#TYPE_CAP[*]}; wv++)); do
+    if [[ ${TYPE_CAP[$wv]} == ${WIDENED_TYPE_CAP[$v]} ]]; then break; fi;
+done
+
+if [[ $root == *Linked* ]]; then
 Linked=Linked
 
 # Macros for transforming the bi-directional long link. Return values are 32-bit int indexes.
@@ -115,18 +126,72 @@ $(if [[ "${CLASS[$k]}" != "" ]]; then\
 	echo "#define KEY_CLASS_${CLASS[$k]} 1\\n";\
 	if [[ "${CLASS[$k]}" != "Object" && "${CLASS[$k]}" != "Reference" ]]; then\
 		echo "#define KEYS_PRIMITIVE 1\\n";\
+		echo "#define JDK_KEY_TO_GENERIC_FUNCTION java.util.function.${TYPE_CAP[$wk]}Function\\n";\
+		if [[ "${CLASS[$k]}" != "Boolean" ]]; then\
+			echo "#define JDK_PRIMITIVE_KEY_CONSUMER java.util.function.${TYPE_CAP[$wk]}Consumer\\n";\
+			echo "#define JDK_PRIMITIVE_PREDICATE java.util.function.${TYPE_CAP[$wk]}Predicate\\n";\
+			echo "#define JDK_PRIMITIVE_ITERATOR PrimitiveIterator.Of${TYPE_CAP[$wk]}\\n";\
+		fi\
 	else\
 		echo "#define KEYS_REFERENCE 1\\n";\
+		echo "#define JDK_KEY_TO_GENERIC_FUNCTION java.util.function.Function\\n";\
+	fi;\
+	if [[ "${CLASS[$k]}" == "Integer" || "${CLASS[$k]}" == "Long" || "${CLASS[$k]}" == "Double" ]]; then\
+		echo "#define JDK_PRIMITIVE_ITERATOR PrimitiveIterator.Of${TYPE_CAP[$k]}\\n";\
 	fi;\
  fi)\
 $(if [[ "${CLASS[$v]}" != "" ]]; then\
 	echo "#define VALUE_CLASS_${CLASS[$v]} 1\\n";\
 	if [[ "${CLASS[$v]}" != "Object" && "${CLASS[$v]}" != "Reference" ]]; then\
 		echo "#define VALUES_PRIMITIVE 1\\n";\
+		if [[ "${CLASS[$v]}" != "Boolean" ]]; then\
+			echo "#define JDK_PRIMITIVE_VALUE_CONSUMER java.util.function.${TYPE_CAP[$wv]}Consumer\\n";\
+		fi\
 	else\
 		echo "#define VALUES_REFERENCE 1\\n";\
 	fi;\
  fi)\
+$(if [[ "${CLASS[$k]}" != "" && "${CLASS[$v]}" != "" ]]; then\
+	if [[ "${TYPE_CAP[$wk]}" == "Int" || "${TYPE_CAP[$wk]}" == "Long" || "${TYPE_CAP[$wk]}" == "Double" ]]; then\
+		if [[ "${TYPE_CAP[$wk]}" == "${TYPE_CAP[$wv]}" ]]; then\
+			echo "#define JDK_PRIMITIVE_FUNCTION java.util.function.${TYPE_CAP[$wk]}UnaryOperator\\n";\
+			echo "#define JDK_PRIMITIVE_FUNCTION_APPLY applyAs${TYPE_CAP[$wv]}\\n";\
+		elif [[ "${TYPE_CAP[$wv]}" == "Boolean" ]]; then\
+			echo "#define JDK_PRIMITIVE_FUNCTION java.util.function.${TYPE_CAP[$wk]}Predicate\\n";\
+			echo "#define JDK_PRIMITIVE_FUNCTION_APPLY test\\n";\
+		elif [[ "${TYPE_CAP[$wv]}" == "Object" || "${TYPE_CAP[$wv]}" == "Reference" ]]; then\
+			echo "#define JDK_PRIMITIVE_FUNCTION java.util.function.${TYPE_CAP[$wk]}Function\\n";\
+			echo "#define JDK_PRIMITIVE_FUNCTION_APPLY apply\\n";\
+		elif [[ "${TYPE_CAP[$wv]}" == "Int" || "${TYPE_CAP[$wv]}" == "Long" || "${TYPE_CAP[$wv]}" == "Double" ]]; then\
+			echo "#define JDK_PRIMITIVE_FUNCTION java.util.function.${TYPE_CAP[$wk]}To${TYPE_CAP[$wv]}Function\\n";\
+			echo "#define JDK_PRIMITIVE_FUNCTION_APPLY applyAs${TYPE_CAP[$wv]}\\n";\
+		fi;\
+	elif [[ "${TYPE_CAP[$wk]}" == "Object" || "${TYPE_CAP[$wk]}" == "Reference" ]]; then\
+		if [[ "${TYPE_CAP[$wv]}" == "Int" || "${TYPE_CAP[$wv]}" == "Long" || "${TYPE_CAP[$wv]}" == "Double" ]]; then\
+			echo "#define JDK_PRIMITIVE_FUNCTION java.util.function.To${TYPE_CAP[$wv]}Function\\n";\
+			echo "#define JDK_PRIMITIVE_FUNCTION_APPLY applyAs${TYPE_CAP[$wv]}\\n";\
+		elif [[ "${TYPE_CAP[$wv]}" == "Boolean" ]]; then\
+			echo "#define JDK_PRIMITIVE_FUNCTION java.util.function.Predicate\\n";\
+			echo "#define JDK_PRIMITIVE_FUNCTION_APPLY test\\n";\
+		fi;\
+	fi;\
+ fi)\
+$(if [[ "${CLASS[$k]}" != "" ]]; then\
+	if [[ "${TYPE[$wk]}" == "${TYPE[$k]}" ]]; then\
+		echo "#define KEY_NARROWING(x) x\\n";\
+	else\
+		echo "#define KEY_NARROWING(x) it.unimi.dsi.fastutil.SafeMath.safe${TYPE_CAP[$wk]}To${TYPE_CAP[$k]}(x)\\n";\
+		echo "#define KEY_WIDENED 1\\n";\
+	fi;\
+fi)\
+$(if [[ "${CLASS[$v]}" != "" ]]; then\
+	if [[ "${TYPE[$wv]}" == "${TYPE[$v]}" ]]; then\
+		echo "#define VALUE_NARROWING(x) x\\n";\
+	else\
+		echo "#define VALUE_NARROWING(x) it.unimi.dsi.fastutil.SafeMath.safe${TYPE_CAP[$wv]}To${TYPE_CAP[$v]}(x)\\n";\
+		echo "#define VALUE_WIDENED 1\\n";\
+	fi;\
+fi)\
 \
 \
 "/* Current type and class (and size, if applicable) */\n"\
@@ -134,17 +199,25 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 \
 "#define KEY_TYPE ${TYPE[$k]}\n"\
 "#define VALUE_TYPE ${TYPE[$v]}\n"\
+"#define KEY_TYPE_WIDENED ${TYPE[$wk]}\n"\
+"#define VALUE_TYPE_WIDENED ${TYPE[$wv]}\n"\
 "#define KEY_CLASS ${CLASS[$k]}\n"\
 "#define VALUE_CLASS ${CLASS[$v]}\n"\
+"#define KEY_CLASS_WIDENED ${CLASS[$wk]}\n"\
+"#define VALUE_CLASS_WIDENED ${CLASS[$wv]}\n"\
 \
 \
 "#if KEYS_REFERENCE\n"\
 "#define KEY_GENERIC_CLASS K\n"\
 "#define KEY_GENERIC_TYPE K\n"\
+"#define KEY_GENERIC_CLASS_WIDENED K\n"\
+"#define KEY_GENERIC_TYPE_WIDENED K\n"\
 "#define KEY_GENERIC <K>\n"\
+"#define KEY_GENERIC_DIAMOND <>\n"\
 "#define KEY_GENERIC_WILDCARD <?>\n"\
 "#define KEY_EXTENDS_GENERIC <? extends K>\n"\
 "#define KEY_SUPER_GENERIC <? super K>\n"\
+"#define KEY_CLASS_CAST (K)\n"\
 "#define KEY_GENERIC_CAST (K)\n"\
 "#define KEY_GENERIC_ARRAY_CAST (K[])\n"\
 "#define KEY_GENERIC_BIG_ARRAY_CAST (K[][])\n"\
@@ -159,10 +232,14 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 "#else\n"\
 "#define KEY_GENERIC_CLASS KEY_CLASS\n"\
 "#define KEY_GENERIC_TYPE KEY_TYPE\n"\
+"#define KEY_GENERIC_CLASS_WIDENED KEY_CLASS_WIDENED\n"\
+"#define KEY_GENERIC_TYPE_WIDENED KEY_TYPE_WIDENED\n"\
 "#define KEY_GENERIC\n"\
+"#define KEY_GENERIC_DIAMOND\n"\
 "#define KEY_GENERIC_WILDCARD\n"\
 "#define KEY_EXTENDS_GENERIC\n"\
 "#define KEY_SUPER_GENERIC\n"\
+"#define KEY_CLASS_CAST (KEY_CLASS)\n"\
 "#define KEY_GENERIC_CAST\n"\
 "#define KEY_GENERIC_ARRAY_CAST\n"\
 "#define KEY_GENERIC_BIG_ARRAY_CAST\n"\
@@ -175,8 +252,12 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 "#if VALUES_REFERENCE\n"\
 "#define VALUE_GENERIC_CLASS V\n"\
 "#define VALUE_GENERIC_TYPE V\n"\
+"#define VALUE_GENERIC_CLASS_WIDENED V\n"\
+"#define VALUE_GENERIC_TYPE_WIDENED V\n"\
 "#define VALUE_GENERIC <V>\n"\
+"#define VALUE_GENERIC_DIAMOND <>\n"\
 "#define VALUE_EXTENDS_GENERIC <? extends V>\n"\
+"#define VALUE_SUPER_GENERIC <? super V>\n"\
 "#define VALUE_GENERIC_CAST (V)\n"\
 "#define VALUE_GENERIC_ARRAY_CAST (V[])\n"\
 "#define SUPPRESS_WARNINGS_VALUE_UNCHECKED @SuppressWarnings(\"unchecked\")\n"\
@@ -184,8 +265,12 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 "#else\n"\
 "#define VALUE_GENERIC_CLASS VALUE_CLASS\n"\
 "#define VALUE_GENERIC_TYPE VALUE_TYPE\n"\
+"#define VALUE_GENERIC_CLASS_WIDENED VALUE_CLASS_WIDENED\n"\
+"#define VALUE_GENERIC_TYPE_WIDENED VALUE_TYPE_WIDENED\n"\
 "#define VALUE_GENERIC\n"\
+"#define VALUE_GENERIC_DIAMOND\n"\
 "#define VALUE_EXTENDS_GENERIC\n"\
+"#define VALUE_SUPER_GENERIC\n"\
 "#define VALUE_GENERIC_CAST\n"\
 "#define VALUE_GENERIC_ARRAY_CAST\n"\
 "#define SUPPRESS_WARNINGS_VALUE_UNCHECKED\n"\
@@ -195,17 +280,21 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 "#if KEYS_REFERENCE\n"\
 "#if VALUES_REFERENCE\n"\
 "#define KEY_VALUE_GENERIC <K,V>\n"\
+"#define KEY_VALUE_GENERIC_DIAMOND <>\n"\
 "#define KEY_VALUE_EXTENDS_GENERIC <? extends K, ? extends V>\n"\
 "#else\n"\
 "#define KEY_VALUE_GENERIC <K>\n"\
+"#define KEY_VALUE_GENERIC_DIAMOND <>\n"\
 "#define KEY_VALUE_EXTENDS_GENERIC <? extends K>\n"\
 "#endif\n"\
 "#else\n"\
 "#if VALUES_REFERENCE\n"\
 "#define KEY_VALUE_GENERIC <V>\n"\
+"#define KEY_VALUE_GENERIC_DIAMOND <>\n"\
 "#define KEY_VALUE_EXTENDS_GENERIC <? extends V>\n"\
 "#else\n"\
 "#define KEY_VALUE_GENERIC\n"\
+"#define KEY_VALUE_GENERIC_DIAMOND\n"\
 "#define KEY_VALUE_EXTENDS_GENERIC\n"\
 "#endif\n"\
 "#endif\n"\
@@ -213,9 +302,11 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 "#if KEYS_REFERENCE || VALUES_REFERENCE\n"\
 "#define SUPPRESS_WARNINGS_KEY_VALUE_UNCHECKED @SuppressWarnings(\"unchecked\")\n"\
 "#define SUPPRESS_WARNINGS_KEY_VALUE_RAWTYPES @SuppressWarnings(\"rawtypes\")\n"\
+"#define SUPPRESS_WARNINGS_KEY_VALUE_UNCHECKED_RAWTYPES @SuppressWarnings({\"rawtypes\", \"unchecked\"})\n"\
 "#else\n"\
 "#define SUPPRESS_WARNINGS_KEY_VALUE_UNCHECKED\n"\
 "#define SUPPRESS_WARNINGS_KEY_VALUE_RAWTYPES\n"\
+"#define SUPPRESS_WARNINGS_KEY_VALUE_UNCHECKED_RAWTYPES\n"\
 "#endif\n"\
 \
 \
@@ -229,170 +320,173 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 "/* Interfaces (keys) */\n"\
 \
 \
-"#define COLLECTION ${TYPE_CAP[$k]}Collection\n\n"\
-"#define SET ${TYPE_CAP[$k]}Set\n\n"\
-"#define HASH ${TYPE_CAP[$k]}Hash\n\n"\
-"#define SORTED_SET ${TYPE_CAP[$k]}SortedSet\n\n"\
-"#define STD_SORTED_SET ${TYPE_STD[$k]}SortedSet\n\n"\
+"#define COLLECTION ${TYPE_CAP[$k]}Collection\n"\
+"#define SET ${TYPE_CAP[$k]}Set\n"\
+"#define HASH ${TYPE_CAP[$k]}Hash\n"\
+"#define SORTED_SET ${TYPE_CAP[$k]}SortedSet\n"\
+"#define STD_SORTED_SET ${TYPE_STD[$k]}SortedSet\n"\
 "#define FUNCTION ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Function\n"\
 "#define MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Map\n"\
 "#define SORTED_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}SortedMap\n"\
 "#if KEYS_REFERENCE\n"\
-"#define STD_SORTED_MAP SortedMap\n\n"\
-"#define STRATEGY Strategy\n\n"\
+"#define STD_SORTED_MAP SortedMap\n"\
+"#define STRATEGY Strategy\n"\
 "#else\n"\
-"#define STD_SORTED_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}SortedMap\n\n"\
-"#define STRATEGY PACKAGE.${TYPE_CAP[$k]}Hash.Strategy\n\n"\
+"#define STD_SORTED_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}SortedMap\n"\
+"#define STRATEGY PACKAGE.${TYPE_CAP[$k]}Hash.Strategy\n"\
 "#endif\n"\
-"#define LIST ${TYPE_CAP[$k]}List\n\n"\
-"#define BIG_LIST ${TYPE_CAP[$k]}BigList\n\n"\
-"#define STACK ${TYPE_STD[$k]}Stack\n\n"\
-"#define PRIORITY_QUEUE ${TYPE_STD[$k]}PriorityQueue\n\n"\
-"#define INDIRECT_PRIORITY_QUEUE ${TYPE_STD[$k]}IndirectPriorityQueue\n\n"\
-"#define INDIRECT_DOUBLE_PRIORITY_QUEUE ${TYPE_STD[$k]}IndirectDoublePriorityQueue\n\n"\
-"#define KEY_ITERATOR ${TYPE_CAP2[$k]}Iterator\n\n"\
-"#define KEY_ITERABLE ${TYPE_CAP2[$k]}Iterable\n\n"\
-"#define KEY_BIDI_ITERATOR ${TYPE_CAP2[$k]}BidirectionalIterator\n\n"\
-"#define KEY_LIST_ITERATOR ${TYPE_CAP2[$k]}ListIterator\n\n"\
-"#define KEY_BIG_LIST_ITERATOR ${TYPE_CAP2[$k]}BigListIterator\n\n"\
-"#define STD_KEY_ITERATOR ${TYPE_STD[$k]}Iterator\n\n"\
-"#define KEY_COMPARATOR ${TYPE_STD[$k]}Comparator\n\n"\
+"#define LIST ${TYPE_CAP[$k]}List\n"\
+"#define BIG_LIST ${TYPE_CAP[$k]}BigList\n"\
+"#define STACK ${TYPE_STD[$k]}Stack\n"\
+"#define PRIORITY_QUEUE ${TYPE_STD[$k]}PriorityQueue\n"\
+"#define INDIRECT_PRIORITY_QUEUE ${TYPE_STD[$k]}IndirectPriorityQueue\n"\
+"#define INDIRECT_DOUBLE_PRIORITY_QUEUE ${TYPE_STD[$k]}IndirectDoublePriorityQueue\n"\
+"#define KEY_CONSUMER ${TYPE_STD[$k]}Consumer\n"\
+"#define KEY_ITERATOR ${TYPE_CAP2[$k]}Iterator\n"\
+"#define KEY_ITERABLE ${TYPE_CAP2[$k]}Iterable\n"\
+"#define KEY_BIDI_ITERATOR ${TYPE_CAP2[$k]}BidirectionalIterator\n"\
+"#define KEY_BIDI_ITERABLE ${TYPE_CAP2[$k]}BidirectionalIterable\n"\
+"#define KEY_LIST_ITERATOR ${TYPE_CAP2[$k]}ListIterator\n"\
+"#define KEY_BIG_LIST_ITERATOR ${TYPE_CAP2[$k]}BigListIterator\n"\
+"#define STD_KEY_ITERATOR ${TYPE_STD[$k]}Iterator\n"\
+"#define KEY_COMPARATOR ${TYPE_STD[$k]}Comparator\n"\
 \
 \
 "/* Interfaces (values) */\n"\
 \
 \
-"#define VALUE_COLLECTION ${TYPE_CAP[$v]}Collection\n\n"\
-"#define VALUE_ARRAY_SET ${TYPE_CAP[$v]}ArraySet\n\n"\
-"#define VALUE_ITERATOR ${TYPE_CAP2[$v]}Iterator\n\n"\
-"#define VALUE_LIST_ITERATOR ${TYPE_CAP2[$v]}ListIterator\n\n"\
+"#define VALUE_COLLECTION ${TYPE_CAP[$v]}Collection\n"\
+"#define VALUE_ARRAY_SET ${TYPE_CAP[$v]}ArraySet\n"\
+"#define VALUE_CONSUMER ${TYPE_STD[$v]}Consumer\n"\
+"#define VALUE_ITERATOR ${TYPE_CAP2[$v]}Iterator\n"\
+"#define VALUE_LIST_ITERATOR ${TYPE_CAP2[$v]}ListIterator\n"\
 \
 \
 "/* Abstract implementations (keys) */\n"\
 \
 \
-"#define ABSTRACT_COLLECTION Abstract${TYPE_CAP[$k]}Collection\n\n"\
-"#define ABSTRACT_SET Abstract${TYPE_CAP[$k]}Set\n\n"\
+"#define ABSTRACT_COLLECTION Abstract${TYPE_CAP[$k]}Collection\n"\
+"#define ABSTRACT_SET Abstract${TYPE_CAP[$k]}Set\n"\
 "#define ABSTRACT_SORTED_SET Abstract${TYPE_CAP[$k]}SortedSet\n"\
 "#define ABSTRACT_FUNCTION Abstract${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Function\n"\
 "#define ABSTRACT_MAP Abstract${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Map\n"\
 "#define ABSTRACT_FUNCTION Abstract${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Function\n"\
 "#define ABSTRACT_SORTED_MAP Abstract${TYPE_CAP[$k]}2${TYPE_CAP[$v]}SortedMap\n"\
-"#define ABSTRACT_LIST Abstract${TYPE_CAP[$k]}List\n\n"\
-"#define ABSTRACT_BIG_LIST Abstract${TYPE_CAP[$k]}BigList\n\n"\
-"#define SUBLIST ${TYPE_CAP[$k]}SubList\n\n"\
-"#define ABSTRACT_PRIORITY_QUEUE Abstract${TYPE_STD[$k]}PriorityQueue\n\n"\
-"#define ABSTRACT_STACK Abstract${TYPE_STD[$k]}Stack\n\n"\
-"#define KEY_ABSTRACT_ITERATOR Abstract${TYPE_CAP2[$k]}Iterator\n\n"\
-"#define KEY_ABSTRACT_BIDI_ITERATOR Abstract${TYPE_CAP2[$k]}BidirectionalIterator\n\n"\
-"#define KEY_ABSTRACT_LIST_ITERATOR Abstract${TYPE_CAP2[$k]}ListIterator\n\n"\
-"#define KEY_ABSTRACT_BIG_LIST_ITERATOR Abstract${TYPE_CAP2[$k]}BigListIterator\n\n"\
+"#define ABSTRACT_LIST Abstract${TYPE_CAP[$k]}List\n"\
+"#define ABSTRACT_BIG_LIST Abstract${TYPE_CAP[$k]}BigList\n"\
+"#define SUBLIST ${TYPE_CAP[$k]}SubList\n"\
+"#define ABSTRACT_PRIORITY_QUEUE Abstract${TYPE_STD[$k]}PriorityQueue\n"\
+"#define ABSTRACT_STACK Abstract${TYPE_STD[$k]}Stack\n"\
+"#define KEY_ABSTRACT_ITERATOR Abstract${TYPE_CAP2[$k]}Iterator\n"\
+"#define KEY_ABSTRACT_BIDI_ITERATOR Abstract${TYPE_CAP2[$k]}BidirectionalIterator\n"\
+"#define KEY_ABSTRACT_LIST_ITERATOR Abstract${TYPE_CAP2[$k]}ListIterator\n"\
+"#define KEY_ABSTRACT_BIG_LIST_ITERATOR Abstract${TYPE_CAP2[$k]}BigListIterator\n"\
 "#if KEY_CLASS_Object\n"\
-"#define KEY_ABSTRACT_COMPARATOR Comparator\n\n"\
+"#define KEY_ABSTRACT_COMPARATOR Comparator\n"\
 "#else\n"\
-"#define KEY_ABSTRACT_COMPARATOR Abstract${TYPE_CAP[$k]}Comparator\n\n"\
+"#define KEY_ABSTRACT_COMPARATOR Abstract${TYPE_CAP[$k]}Comparator\n"\
 "#endif\n"\
 \
 \
 "/* Abstract implementations (values) */\n"\
 \
 \
-"#define VALUE_ABSTRACT_COLLECTION Abstract${TYPE_CAP[$v]}Collection\n\n"\
-"#define VALUE_ABSTRACT_ITERATOR Abstract${TYPE_CAP2[$v]}Iterator\n\n"\
-"#define VALUE_ABSTRACT_BIDI_ITERATOR Abstract${TYPE_CAP2[$v]}BidirectionalIterator\n\n"\
+"#define VALUE_ABSTRACT_COLLECTION Abstract${TYPE_CAP[$v]}Collection\n"\
+"#define VALUE_ABSTRACT_ITERATOR Abstract${TYPE_CAP2[$v]}Iterator\n"\
+"#define VALUE_ABSTRACT_BIDI_ITERATOR Abstract${TYPE_CAP2[$v]}BidirectionalIterator\n"\
 \
 \
 "/* Static containers (keys) */\n"\
 \
 \
-"#define COLLECTIONS ${TYPE_CAP[$k]}Collections\n\n"\
-"#define SETS ${TYPE_CAP[$k]}Sets\n\n"\
-"#define SORTED_SETS ${TYPE_CAP[$k]}SortedSets\n\n"\
-"#define LISTS ${TYPE_CAP[$k]}Lists\n\n"\
-"#define BIG_LISTS ${TYPE_CAP[$k]}BigLists\n\n"\
+"#define COLLECTIONS ${TYPE_CAP[$k]}Collections\n"\
+"#define SETS ${TYPE_CAP[$k]}Sets\n"\
+"#define SORTED_SETS ${TYPE_CAP[$k]}SortedSets\n"\
+"#define LISTS ${TYPE_CAP[$k]}Lists\n"\
+"#define BIG_LISTS ${TYPE_CAP[$k]}BigLists\n"\
 "#define MAPS ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Maps\n"\
 "#define FUNCTIONS ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Functions\n"\
 "#define SORTED_MAPS ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}SortedMaps\n"\
-"#define PRIORITY_QUEUES ${TYPE_CAP2[$k]}PriorityQueues\n\n"\
-"#define HEAPS ${TYPE_CAP2[$k]}Heaps\n\n"\
-"#define SEMI_INDIRECT_HEAPS ${TYPE_CAP2[$k]}SemiIndirectHeaps\n\n"\
-"#define INDIRECT_HEAPS ${TYPE_CAP2[$k]}IndirectHeaps\n\n"\
-"#define ARRAYS ${TYPE_CAP2[$k]}Arrays\n\n"\
-"#define BIG_ARRAYS ${TYPE_CAP2[$k]}BigArrays\n\n"\
-"#define ITERATORS ${TYPE_CAP2[$k]}Iterators\n\n"\
-"#define BIG_LIST_ITERATORS ${TYPE_CAP2[$k]}BigListIterators\n\n"\
-"#define COMPARATORS ${TYPE_CAP2[$k]}Comparators\n\n"\
+"#define PRIORITY_QUEUES ${TYPE_CAP2[$k]}PriorityQueues\n"\
+"#define HEAPS ${TYPE_CAP2[$k]}Heaps\n"\
+"#define SEMI_INDIRECT_HEAPS ${TYPE_CAP2[$k]}SemiIndirectHeaps\n"\
+"#define INDIRECT_HEAPS ${TYPE_CAP2[$k]}IndirectHeaps\n"\
+"#define ARRAYS ${TYPE_CAP2[$k]}Arrays\n"\
+"#define BIG_ARRAYS ${TYPE_CAP2[$k]}BigArrays\n"\
+"#define ITERATORS ${TYPE_CAP2[$k]}Iterators\n"\
+"#define BIG_LIST_ITERATORS ${TYPE_CAP2[$k]}BigListIterators\n"\
+"#define COMPARATORS ${TYPE_CAP2[$k]}Comparators\n"\
 \
 \
 "/* Static containers (values) */\n"\
 \
 \
-"#define VALUE_COLLECTIONS ${TYPE_CAP[$v]}Collections\n\n"\
-"#define VALUE_SETS ${TYPE_CAP[$v]}Sets\n\n"\
-"#define VALUE_ARRAYS ${TYPE_CAP2[$v]}Arrays\n\n"\
+"#define VALUE_COLLECTIONS ${TYPE_CAP[$v]}Collections\n"\
+"#define VALUE_SETS ${TYPE_CAP[$v]}Sets\n"\
+"#define VALUE_ARRAYS ${TYPE_CAP2[$v]}Arrays\n"\
 \
 \
 "/* Implementations */\n"\
 \
 \
-"#define OPEN_HASH_SET ${TYPE_CAP[$k]}${Linked}Open${Custom}HashSet\n\n"\
-"#define OPEN_HASH_BIG_SET ${TYPE_CAP[$k]}${Linked}Open${Custom}HashBigSet\n\n"\
-"#define OPEN_DOUBLE_HASH_SET ${TYPE_CAP[$k]}${Linked}Open${Custom}DoubleHashSet\n\n"\
-"#define OPEN_HASH_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}${Linked}Open${Custom}HashMap\n\n"\
-"#define OPEN_HASH_BIG_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}${Linked}Open${Custom}HashBigMap\n\n"\
-"#define STRIPED_OPEN_HASH_MAP Striped${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Open${Custom}HashMap\n\n"\
-"#define OPEN_DOUBLE_HASH_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}${Linked}Open${Custom}DoubleHashMap\n\n"\
-"#define ARRAY_SET ${TYPE_CAP[$k]}ArraySet\n\n"\
-"#define ARRAY_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}ArrayMap\n\n"\
-"#define LINKED_OPEN_HASH_SET ${TYPE_CAP[$k]}LinkedOpenHashSet\n\n"\
-"#define AVL_TREE_SET ${TYPE_CAP[$k]}AVLTreeSet\n\n"\
-"#define RB_TREE_SET ${TYPE_CAP[$k]}RBTreeSet\n\n"\
-"#define AVL_TREE_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}AVLTreeMap\n\n"\
-"#define RB_TREE_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}RBTreeMap\n\n"\
-"#define ARRAY_LIST ${TYPE_CAP[$k]}ArrayList\n\n"\
-"#define BIG_ARRAY_BIG_LIST ${TYPE_CAP[$k]}BigArrayBigList\n\n"\
-"#define ARRAY_FRONT_CODED_LIST ${TYPE_CAP[$k]}ArrayFrontCodedList\n\n"\
-"#define HEAP_PRIORITY_QUEUE ${TYPE_CAP2[$k]}HeapPriorityQueue\n\n"\
-"#define HEAP_SEMI_INDIRECT_PRIORITY_QUEUE ${TYPE_CAP2[$k]}HeapSemiIndirectPriorityQueue\n\n"\
-"#define HEAP_INDIRECT_PRIORITY_QUEUE ${TYPE_CAP2[$k]}HeapIndirectPriorityQueue\n\n"\
-"#define HEAP_SESQUI_INDIRECT_DOUBLE_PRIORITY_QUEUE ${TYPE_CAP2[$k]}HeapSesquiIndirectDoublePriorityQueue\n\n"\
-"#define HEAP_INDIRECT_DOUBLE_PRIORITY_QUEUE ${TYPE_CAP2[$k]}HeapIndirectDoublePriorityQueue\n\n"\
-"#define ARRAY_FIFO_QUEUE ${TYPE_CAP2[$k]}ArrayFIFOQueue\n\n"\
-"#define ARRAY_PRIORITY_QUEUE ${TYPE_CAP2[$k]}ArrayPriorityQueue\n\n"\
-"#define ARRAY_INDIRECT_PRIORITY_QUEUE ${TYPE_CAP2[$k]}ArrayIndirectPriorityQueue\n\n"\
-"#define ARRAY_INDIRECT_DOUBLE_PRIORITY_QUEUE ${TYPE_CAP2[$k]}ArrayIndirectDoublePriorityQueue\n\n"\
+"#define OPEN_HASH_SET ${TYPE_CAP[$k]}${Linked}Open${Custom}HashSet\n"\
+"#define OPEN_HASH_BIG_SET ${TYPE_CAP[$k]}${Linked}Open${Custom}HashBigSet\n"\
+"#define OPEN_DOUBLE_HASH_SET ${TYPE_CAP[$k]}${Linked}Open${Custom}DoubleHashSet\n"\
+"#define OPEN_HASH_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}${Linked}Open${Custom}HashMap\n"\
+"#define OPEN_HASH_BIG_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}${Linked}Open${Custom}HashBigMap\n"\
+"#define STRIPED_OPEN_HASH_MAP Striped${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Open${Custom}HashMap\n"\
+"#define OPEN_DOUBLE_HASH_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}${Linked}Open${Custom}DoubleHashMap\n"\
+"#define ARRAY_SET ${TYPE_CAP[$k]}ArraySet\n"\
+"#define ARRAY_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}ArrayMap\n"\
+"#define LINKED_OPEN_HASH_SET ${TYPE_CAP[$k]}LinkedOpenHashSet\n"\
+"#define AVL_TREE_SET ${TYPE_CAP[$k]}AVLTreeSet\n"\
+"#define RB_TREE_SET ${TYPE_CAP[$k]}RBTreeSet\n"\
+"#define AVL_TREE_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}AVLTreeMap\n"\
+"#define RB_TREE_MAP ${TYPE_CAP[$k]}2${TYPE_CAP[$v]}RBTreeMap\n"\
+"#define ARRAY_LIST ${TYPE_CAP[$k]}ArrayList\n"\
+"#define BIG_ARRAY_BIG_LIST ${TYPE_CAP[$k]}BigArrayBigList\n"\
+"#define ARRAY_FRONT_CODED_LIST ${TYPE_CAP[$k]}ArrayFrontCodedList\n"\
+"#define HEAP_PRIORITY_QUEUE ${TYPE_CAP2[$k]}HeapPriorityQueue\n"\
+"#define HEAP_SEMI_INDIRECT_PRIORITY_QUEUE ${TYPE_CAP2[$k]}HeapSemiIndirectPriorityQueue\n"\
+"#define HEAP_INDIRECT_PRIORITY_QUEUE ${TYPE_CAP2[$k]}HeapIndirectPriorityQueue\n"\
+"#define HEAP_SESQUI_INDIRECT_DOUBLE_PRIORITY_QUEUE ${TYPE_CAP2[$k]}HeapSesquiIndirectDoublePriorityQueue\n"\
+"#define HEAP_INDIRECT_DOUBLE_PRIORITY_QUEUE ${TYPE_CAP2[$k]}HeapIndirectDoublePriorityQueue\n"\
+"#define ARRAY_FIFO_QUEUE ${TYPE_CAP2[$k]}ArrayFIFOQueue\n"\
+"#define ARRAY_PRIORITY_QUEUE ${TYPE_CAP2[$k]}ArrayPriorityQueue\n"\
+"#define ARRAY_INDIRECT_PRIORITY_QUEUE ${TYPE_CAP2[$k]}ArrayIndirectPriorityQueue\n"\
+"#define ARRAY_INDIRECT_DOUBLE_PRIORITY_QUEUE ${TYPE_CAP2[$k]}ArrayIndirectDoublePriorityQueue\n"\
 \
 \
 "/* Synchronized wrappers */\n"\
 \
 \
-"#define SYNCHRONIZED_COLLECTION Synchronized${TYPE_CAP[$k]}Collection\n\n"\
-"#define SYNCHRONIZED_SET Synchronized${TYPE_CAP[$k]}Set\n\n"\
-"#define SYNCHRONIZED_SORTED_SET Synchronized${TYPE_CAP[$k]}SortedSet\n\n"\
-"#define SYNCHRONIZED_FUNCTION Synchronized${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Function\n\n"\
-"#define SYNCHRONIZED_MAP Synchronized${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Map\n\n"\
-"#define SYNCHRONIZED_LIST Synchronized${TYPE_CAP[$k]}List\n\n"\
+"#define SYNCHRONIZED_COLLECTION Synchronized${TYPE_CAP[$k]}Collection\n"\
+"#define SYNCHRONIZED_SET Synchronized${TYPE_CAP[$k]}Set\n"\
+"#define SYNCHRONIZED_SORTED_SET Synchronized${TYPE_CAP[$k]}SortedSet\n"\
+"#define SYNCHRONIZED_FUNCTION Synchronized${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Function\n"\
+"#define SYNCHRONIZED_MAP Synchronized${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Map\n"\
+"#define SYNCHRONIZED_LIST Synchronized${TYPE_CAP[$k]}List\n"\
 \
 \
 "/* Unmodifiable wrappers */\n"\
 \
 \
-"#define UNMODIFIABLE_COLLECTION Unmodifiable${TYPE_CAP[$k]}Collection\n\n"\
-"#define UNMODIFIABLE_SET Unmodifiable${TYPE_CAP[$k]}Set\n\n"\
-"#define UNMODIFIABLE_SORTED_SET Unmodifiable${TYPE_CAP[$k]}SortedSet\n\n"\
-"#define UNMODIFIABLE_FUNCTION Unmodifiable${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Function\n\n"\
-"#define UNMODIFIABLE_MAP Unmodifiable${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Map\n\n"\
-"#define UNMODIFIABLE_LIST Unmodifiable${TYPE_CAP[$k]}List\n\n"\
-"#define UNMODIFIABLE_KEY_ITERATOR Unmodifiable${TYPE_CAP[$k]}Iterator\n\n"\
-"#define UNMODIFIABLE_KEY_BIDI_ITERATOR Unmodifiable${TYPE_CAP[$k]}BidirectionalIterator\n\n"\
-"#define UNMODIFIABLE_KEY_LIST_ITERATOR Unmodifiable${TYPE_CAP[$k]}ListIterator\n\n"\
+"#define UNMODIFIABLE_COLLECTION Unmodifiable${TYPE_CAP[$k]}Collection\n"\
+"#define UNMODIFIABLE_SET Unmodifiable${TYPE_CAP[$k]}Set\n"\
+"#define UNMODIFIABLE_SORTED_SET Unmodifiable${TYPE_CAP[$k]}SortedSet\n"\
+"#define UNMODIFIABLE_FUNCTION Unmodifiable${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Function\n"\
+"#define UNMODIFIABLE_MAP Unmodifiable${TYPE_CAP[$k]}2${TYPE_CAP[$v]}Map\n"\
+"#define UNMODIFIABLE_LIST Unmodifiable${TYPE_CAP[$k]}List\n"\
+"#define UNMODIFIABLE_KEY_ITERATOR Unmodifiable${TYPE_CAP[$k]}Iterator\n"\
+"#define UNMODIFIABLE_KEY_BIDI_ITERATOR Unmodifiable${TYPE_CAP[$k]}BidirectionalIterator\n"\
+"#define UNMODIFIABLE_KEY_LIST_ITERATOR Unmodifiable${TYPE_CAP[$k]}ListIterator\n"\
 \
 \
 "/* Other wrappers */\n"\
 \
 \
-"#define KEY_READER_WRAPPER ${TYPE_CAP[$k]}ReaderWrapper\n\n"\
-"#define KEY_DATA_INPUT_WRAPPER ${TYPE_CAP[$k]}DataInputWrapper\n\n"\
+"#define KEY_READER_WRAPPER ${TYPE_CAP[$k]}ReaderWrapper\n"\
+"#define KEY_DATA_INPUT_WRAPPER ${TYPE_CAP[$k]}DataInputWrapper\n"\
 \
 \
 "/* Methods (keys) */\n"\
@@ -400,6 +494,8 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 \
 "#define NEXT_KEY next${TYPE_STD[$k]}\n"\
 "#define PREV_KEY previous${TYPE_STD[$k]}\n"\
+"#define NEXT_KEY_WIDENED next${TYPE_STD[$wk]}\n"\
+"#define PREV_KEY_WIDENED previous${TYPE_STD[$wk]}\n"\
 "#define FIRST_KEY first${TYPE_STD[$k]}Key\n"\
 "#define LAST_KEY last${TYPE_STD[$k]}Key\n"\
 "#define GET_KEY get${TYPE_STD[$k]}\n"\
@@ -408,18 +504,16 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 "#define WRITE_KEY write${TYPE_CAP2[$k]}\n"\
 "#define DEQUEUE dequeue${TYPE_STD[$k]}\n"\
 "#define DEQUEUE_LAST dequeueLast${TYPE_STD[$k]}\n"\
-"#define SUBLIST_METHOD ${TYPE_LC[$k]}SubList\n"\
-"#define SINGLETON_METHOD ${TYPE_LC[$k]}Singleton\n\n"\
+"#define SINGLETON_METHOD ${TYPE_LC[$k]}Singleton\n"\
 "#define FIRST first${TYPE_STD[$k]}\n"\
 "#define LAST last${TYPE_STD[$k]}\n"\
 "#define TOP top${TYPE_STD[$k]}\n"\
 "#define PEEK peek${TYPE_STD[$k]}\n"\
 "#define POP pop${TYPE_STD[$k]}\n"\
-"#define KEY_ITERATOR_METHOD ${TYPE_LC2[$k]}Iterator\n\n"\
-"#define KEY_LIST_ITERATOR_METHOD ${TYPE_LC2[$k]}ListIterator\n\n"\
-"#define KEY_EMPTY_ITERATOR_METHOD empty${TYPE_CAP2[$k]}Iterator\n\n"\
-"#define AS_KEY_ITERATOR as${TYPE_CAP2[$k]}Iterator\n\n"\
-"#define AS_KEY_ITERABLE as${TYPE_CAP2[$k]}Iterable\n\n"\
+"#define KEY_EMPTY_ITERATOR_METHOD empty${TYPE_CAP2[$k]}Iterator\n"\
+"#define AS_KEY_ITERATOR as${TYPE_CAP2[$k]}Iterator\n"\
+"#define AS_KEY_COMPARATOR as${TYPE_CAP2[$k]}Comparator\n"\
+"#define AS_KEY_ITERABLE as${TYPE_CAP2[$k]}Iterable\n"\
 "#define TO_KEY_ARRAY to${TYPE_STD[$k]}Array\n"\
 "#define ENTRY_GET_KEY get${TYPE_STD[$k]}Key\n"\
 "#define REMOVE_FIRST_KEY removeFirst${TYPE_STD[$k]}\n"\
@@ -437,7 +531,6 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 "#define PREV_VALUE previous${TYPE_STD[$v]}\n"\
 "#define READ_VALUE read${TYPE_CAP2[$v]}\n"\
 "#define WRITE_VALUE write${TYPE_CAP2[$v]}\n"\
-"#define VALUE_ITERATOR_METHOD ${TYPE_LC2[$v]}Iterator\n\n"\
 "#define ENTRY_GET_VALUE get${TYPE_STD[$v]}Value\n"\
 "#define REMOVE_FIRST_VALUE removeFirst${TYPE_STD[$v]}\n"\
 "#define REMOVE_LAST_VALUE removeLast${TYPE_STD[$v]}\n"\
@@ -455,9 +548,21 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 "#if KEYS_REFERENCE\n"\
 "#define GET_VALUE get${TYPE_STD[$v]}\n"\
 "#define REMOVE_VALUE remove${TYPE_STD[$v]}\n"\
+"#define COMPUTE_IF_ABSENT_JDK compute${TYPE_CAP[$v]}IfAbsent\n"\
+"#define COMPUTE_IF_ABSENT_NULLABLE compute${TYPE_CAP[$v]}IfAbsentNullable\n"\
+"#define COMPUTE_IF_ABSENT_PARTIAL compute${TYPE_CAP[$v]}IfAbsentPartial\n"\
+"#define COMPUTE compute${TYPE_STD[$v]}\n"\
+"#define COMPUTE_IF_PRESENT compute${TYPE_STD[$v]}IfPresent\n"\
+"#define MERGE merge${TYPE_STD[$v]}\n"\
 "#else\n"\
 "#define GET_VALUE get\n"\
 "#define REMOVE_VALUE remove\n"\
+"#define COMPUTE_IF_ABSENT_JDK computeIfAbsent\n"\
+"#define COMPUTE_IF_ABSENT_NULLABLE computeIfAbsentNullable\n"\
+"#define COMPUTE_IF_ABSENT_PARTIAL computeIfAbsentPartial\n"\
+"#define COMPUTE compute\n"\
+"#define COMPUTE_IF_PRESENT computeIfPresent\n"\
+"#define MERGE merge\n"\
 "#endif\n"\
 \
 \
@@ -467,9 +572,9 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 \
 \
 "#define KEY_EQUALS_NOT_NULL_CAST(x,y) KEY_EQUALS_NOT_NULL(x,y)\n"\
-"#define KEY2INTHASH_CAST(x) KEY2INTHASH(x)\n\n"\
+"#define KEY2INTHASH_CAST(x) KEY2INTHASH(x)\n"\
 "#if KEY_CLASS_Object\n"\
-"#define KEY_EQUALS(x,y) ( (x) == null ? (y) == null : (x).equals(y) )\n"\
+"#define KEY_EQUALS(x,y) java.util.Objects.equals(x, y)\n"\
 "#define KEY_EQUALS_NOT_NULL(x,y) ( (x).equals(y) )\n"\
 "#define KEY_IS_NULL(x) ( (x) == null )\n"\
 "#elif KEY_CLASS_Float\n"\
@@ -484,7 +589,7 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 "#define KEY_EQUALS(x,y) ( (x) == (y) )\n"\
 "#define KEY_EQUALS_NOT_NULL(x,y) ( (x) == (y) )\n"\
 "#define KEY_IS_NULL(x) ( (x) == KEY_NULL )\n"\
-"#endif\n\n"\
+"#endif\n"\
 \
 "#ifdef Custom\n"\
 "#undef KEY_EQUALS\n"\
@@ -496,13 +601,27 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 "#define KEY_EQUALS_NULL(x) ( strategy.equals( (x), KEY_NULL ) )\n"\
 "#else\n"\
 "#define KEY_EQUALS_NULL(x) KEY_IS_NULL(x)\n"\
-"#endif\n\n"\
+"#endif\n"\
 \
+"#define VALUE_EQUALS_NOT_NULL_CAST(x,y) VALUE_EQUALS_NOT_NULL(x,y)\n"\
+"#define VALUE2INTHASH_CAST(x) VALUE2INTHASH(x)\n"\
 "#if VALUE_CLASS_Object\n"\
-"#define VALUE_EQUALS(x,y) ( (x) == null ? (y) == null : (x).equals(y) )\n"\
+"#define VALUE_EQUALS(x,y) java.util.Objects.equals(x, y)\n"\
+"#define VALUE_EQUALS_NOT_NULL(x,y) ( (x).equals(y) )\n"\
+"#define VALUE_IS_NULL(x) ( (x) == null )\n"\
+"#elif VALUE_CLASS_Float\n"\
+"#define VALUE_EQUALS(x,y) ( Float.floatToIntBits(x) == Float.floatToIntBits(y) )\n"\
+"#define VALUE_EQUALS_NOT_NULL(x,y) ( Float.floatToIntBits(x) == Float.floatToIntBits(y) )\n"\
+"#define VALUE_IS_NULL(x) ( Float.floatToIntBits(x) == 0 )\n"\
+"#elif VALUE_CLASS_Double\n"\
+"#define VALUE_EQUALS(x,y) ( Double.doubleToLongBits(x) == Double.doubleToLongBits(y) )\n"\
+"#define VALUE_EQUALS_NOT_NULL(x,y) ( Double.doubleToLongBits(x) == Double.doubleToLongBits(y) )\n"\
+"#define VALUE_IS_NULL(x) ( Double.doubleToLongBits(x) == 0 )\n"\
 "#else\n"\
 "#define VALUE_EQUALS(x,y) ( (x) == (y) )\n"\
-"#endif\n\n"\
+"#define VALUE_EQUALS_NOT_NULL(x,y) ( (x) == (y) )\n"\
+"#define VALUE_IS_NULL(x) ( (x) == VALUE_NULL )\n"\
+"#endif\n"\
 \
 \
 \
@@ -550,9 +669,9 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 \
 "#define REMOVE rem\n"\
 \
-"#define KEY_CLASS2TYPE(x) ((x).KEY_VALUE())\n"\
-"#define KEY_OBJ2TYPE(x) (KEY_CLASS2TYPE((KEY_CLASS)(x)))\n"\
-"#define KEY2OBJ(x) (KEY_CLASS.valueOf(x))\n"\
+"#define KEY_CLASS2TYPE(x) (x).KEY_VALUE()\n"\
+"#define KEY_OBJ2TYPE(x) KEY_CLASS2TYPE((KEY_CLASS)(x))\n"\
+"#define KEY2OBJ(x) KEY_CLASS.valueOf(x)\n"\
 \
 "#if KEY_CLASS_Boolean\n"\
 "#define KEY_CMP_EQ(x,y) ( (x) == (y) )\n"\
@@ -644,7 +763,6 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 "#endif\n"\
 \
 "#define VALUE_NULL (null)\n"\
-"#define OBJECT_DEFAULT_RETURN_VALUE (this.defRetValue)\n"\
 \
 "#else\n"\
 \
@@ -652,9 +770,9 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 "/* Primitive-type-only definitions (values) */\n"\
 \
 \
-"#define VALUE_CLASS2TYPE(x) ((x).VALUE_VALUE())\n"\
-"#define VALUE_OBJ2TYPE(x) (VALUE_CLASS2TYPE((VALUE_CLASS)(x)))\n"\
-"#define VALUE2OBJ(x) (VALUE_CLASS.valueOf(x))\n"\
+"#define VALUE_CLASS2TYPE(x) (x).VALUE_VALUE()\n"\
+"#define VALUE_OBJ2TYPE(x) VALUE_CLASS2TYPE((VALUE_CLASS)(x))\n"\
+"#define VALUE2OBJ(x) VALUE_CLASS.valueOf(x)\n"\
 \
 "#if VALUE_CLASS_Float || VALUE_CLASS_Double || VALUE_CLASS_Long\n"\
 "#define VALUE_NULL (0)\n"\
@@ -671,8 +789,7 @@ $(if [[ "${CLASS[$v]}" != "" ]]; then\
 "#define VALUE2JAVAHASH(x) (x)\n"\
 "#endif\n"\
 \
-"#define OBJECT_DEFAULT_RETURN_VALUE (null)\n"\
-\
 "#endif\n"\
 \
+"/* START_OF_JAVA_SOURCE */\n"\
 "#include \"$1\"\n"
