@@ -1,6 +1,6 @@
 package it.unimi.dsi.fastutil;
 
-/*		 
+/*
  * Copyright (C) 2003-2017 Paolo Boldi and Sebastiano Vigna
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -13,23 +13,13 @@ package it.unimi.dsi.fastutil;
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
- * limitations under the License. 
+ * limitations under the License.
  */
 
-import it.unimi.dsi.fastutil.PriorityQueue;
-
-/**  An abstract class providing basic methods for implementing the {@link PriorityQueue} interface. 
+/**  An abstract class providing basic methods for implementing the {@link PriorityQueue} interface.
  *
- * <P>This class defines {@link #changed()} and {@link #last()} as throwing an
- * {@link UnsupportedOperationException}.
+ * @deprecated As of fastutil 8 this class is no longer necessary, as its previous abstract
+ * methods are now default methods of {@link PriorityQueue}.
  */
-
-public abstract class AbstractPriorityQueue<K> implements PriorityQueue<K> {
-
-	public void changed() { throw new UnsupportedOperationException(); }
-
-	public K last() { throw new UnsupportedOperationException(); }
-
-	public boolean isEmpty() { return size() == 0; }
-
-}
+@Deprecated
+public abstract class AbstractPriorityQueue<K> implements PriorityQueue<K> {}
