@@ -1,6 +1,6 @@
 package it.unimi.dsi.fastutil;
 
-/*		 
+/*
  * Copyright (C) 2010-2017 Sebastiano Vigna
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -13,7 +13,7 @@ package it.unimi.dsi.fastutil;
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
- * limitations under the License. 
+ * limitations under the License.
  *
  * For the sorting code:
  *
@@ -25,7 +25,7 @@ package it.unimi.dsi.fastutil;
  *   both that copyright notice and this permission notice appear in
  *   supporting documentation. CERN makes no representations about the
  *   suitability of this software for any purpose. It is provided "as is"
- *   without expressed or implied warranty. 
+ *   without expressed or implied warranty.
  */
 
 
@@ -36,24 +36,24 @@ import it.unimi.dsi.fastutil.longs.LongComparator;
 /**
  * A class providing static methods and objects that do useful things with big
  * arrays.
- * 
+ *
  * <h2>Introducing big arrays</h2>
- * 
+ *
  * <p>
  * A <em>big array</em> is an array-of-arrays representation of an array. The
  * length of a big array is bounded by {@link #SEGMENT_SIZE} *
  * {@link Integer#MAX_VALUE} = {@value #SEGMENT_SIZE} * (2<sup>31</sup> &minus;
  * 1) rather than {@link Integer#MAX_VALUE}. The type of a big array is that of
  * an array-of-arrays, so a big array of integers is of type
- * <code>int[][]</code>. Note that {@link #SEGMENT_SIZE} has been chosen so that
+ * {@code int[][]}. Note that {@link #SEGMENT_SIZE} has been chosen so that
  * a single segment is smaller than 2<sup>31</sup> bytes independently of the
  * data type. It might be enlarged in the future.
- * 
+ *
  * <p>
- * If <code>a</code> is a big array, <code>a[0]</code>, <code>a[1]</code>,
+ * If {@code a} is a big array, {@code a[0]}, {@code a[1]},
  * &hellip; are called the <em>segments</em> of the big array. All segments,
  * except possibly for the last one, are of length {@link #SEGMENT_SIZE}. Given
- * an index <code>i</code> into a big array, there is an associated
+ * an index {@code i} into a big array, there is an associated
  * <em>{@linkplain #segment(long) segment}</em> and an associated
  * <em>{@linkplain #displacement(long)
  * displacement}</em> into that segment. Access to single members happens by
@@ -62,12 +62,12 @@ import it.unimi.dsi.fastutil.longs.LongComparator;
  * {@link IntBigArrays#set(int[][], long, int)}), but you can also use the
  * methods {@link #segment(long)}/{@link #displacement(long)} to access entries
  * manually.
- * 
+ *
  * <h2>Scanning big arrays</h2>
- * 
+ *
  * <p>
  * You can scan a big array using the following idiomatic form:
- * 
+ *
  * <pre>
  * for(int s = 0; s &lt; a.length; s++) {
  *     final int[] t = a[s];
@@ -77,33 +77,33 @@ import it.unimi.dsi.fastutil.longs.LongComparator;
  *     }
  * }
  * </pre>
- * 
+ *
  * or using the (simpler and usually faster) reversed version:
- * 
+ *
  * <pre>
- * for( int s = a.length; s-- != 0;) {
+ * for(int s = a.length; s-- != 0;) {
  *     final int[] t = a[s];
- *     for( int d = t.length; d-- != 0;) {
+ *     for(int d = t.length; d-- != 0;) {
  *         do something with t[d]
  *     }
  * }
  * </pre>
  * <p>
- * Inside the inner loop, the original index in <code>a</code> can be retrieved
- * using {@link #index(int, int) index(segment, displacement)}. You can also 
+ * Inside the inner loop, the original index in {@code a} can be retrieved
+ * using {@link #index(int, int) index(segment, displacement)}. You can also
  * use an additional long to keep track of the index.
- * 
+ *
  * <p>
  * Note that caching is essential in making these loops essentially as fast as
  * those scanning standard arrays (as iterations of the outer loop happen very
  * rarely). Using loops of this kind is extremely faster than using a standard
  * loop and accessors.
- * 
+ *
  * <p>
  * In some situations, you might want to iterate over a part of a big array
  * having an offset and a length. In this case, the idiomatic loops are as
  * follows:
- * 
+ *
  * <pre>
  * for(int s = segment(offset); s &lt; segment(offset + length + SEGMENT_MASK); s++) {
  *     final int[] t = a[s];
@@ -113,9 +113,9 @@ import it.unimi.dsi.fastutil.longs.LongComparator;
  *     }
  * }
  * </pre>
- * 
+ *
  * or, in a reversed form,
- * 
+ *
  * <pre>
  * for(int s = segment(offset + length + SEGMENT_MASK); s-- != segment(offset);) {
  *     final int[] t = a[s];
@@ -125,20 +125,20 @@ import it.unimi.dsi.fastutil.longs.LongComparator;
  *     }
  * }
  * </pre>
- * 
+ *
  * <h2>Literal big arrays</h2>
- * 
+ *
  * <p>
  * A literal big array can be easily created by using the suitable type-specific
- * <code>wrap()</code> method (e.g., {@link IntBigArrays#wrap(int[])}) around a
+ * {@code wrap()} method (e.g., {@link IntBigArrays#wrap(int[])}) around a
  * literal standard array. Alternatively, for very small arrays you can just
- * declare a literal array-of-array (e.g., <code>new int[][] { { 1, 2 } }</code>
- * ). Be warned, however, that this can lead to creating illegal big arrays if
+ * declare a literal array-of-array (e.g., <code>new int[][] { { 1, 2 } }</code>).
+ * Be warned, however, that this can lead to creating illegal big arrays if
  * for some reason (e.g., stress testing) {@link #SEGMENT_SIZE} is set to a
  * value smaller than the inner array length.
- * 
+ *
  * <h2>Big alternatives</h2>
- * 
+ *
  * <p>
  * If you find the kind of &ldquo;bare hands&rdquo; approach to big arrays not
  * enough object-oriented, please use big lists based on big arrays (.e.g,
@@ -148,7 +148,7 @@ import it.unimi.dsi.fastutil.longs.LongComparator;
  * object-oriented approach, but provides some significant performance gains.
  *
  * <h2>Additional methods</h2>
- * 
+ *
  * <p>
  * In addition to commodity methods, this class contains {@link BigSwapper}
  * -based implementations of
@@ -166,22 +166,22 @@ public class BigArrays {
 	 * The shift used to compute the segment associated with an index
 	 * (equivalently, the logarithm of the segment size).
 	 */
-	public final static int SEGMENT_SHIFT = 27;
+	public static final int SEGMENT_SHIFT = 27;
 	/**
 	 * The current size of a segment (2<sup>27</sup>) is the largest size that
 	 * makes the physical memory allocation for a single segment strictly
 	 * smaller than 2<sup>31</sup> bytes.
 	 */
-	public final static int SEGMENT_SIZE = 1 << SEGMENT_SHIFT;
+	public static final int SEGMENT_SIZE = 1 << SEGMENT_SHIFT;
 	/** The mask used to compute the displacement associated to an index. */
-	public final static int SEGMENT_MASK = SEGMENT_SIZE - 1;
+	public static final int SEGMENT_MASK = SEGMENT_SIZE - 1;
 
 	protected BigArrays() {
 	}
 
 	/**
 	 * Computes the segment associated with a given index.
-	 * 
+	 *
 	 * @param index
 	 *            an index into a big array.
 	 * @return the associated segment.
@@ -192,7 +192,7 @@ public class BigArrays {
 
 	/**
 	 * Computes the displacement associated with a given index.
-	 * 
+	 *
 	 * @param index
 	 *            an index into a big array.
 	 * @return the associated displacement (in the associated
@@ -204,7 +204,7 @@ public class BigArrays {
 
 	/**
 	 * Computes the starting index of a given segment.
-	 * 
+	 *
 	 * @param segment
 	 *            the segment of a big array.
 	 * @return the starting index of the segment.
@@ -215,7 +215,7 @@ public class BigArrays {
 
 	/**
 	 * Computes the index associated with given segment and displacement.
-	 * 
+	 *
 	 * @param segment
 	 *            the segment of a big array.
 	 * @param displacement
@@ -233,7 +233,7 @@ public class BigArrays {
 	 * Ensures that a range given by its first (inclusive) and last (exclusive)
 	 * elements fits a big array of given length.
 	 *
-	 * <P>
+	 * <p>
 	 * This method may be used whenever a big array range check is needed.
 	 *
 	 * @param bigArrayLength
@@ -243,10 +243,10 @@ public class BigArrays {
 	 * @param to
 	 *            an end index (inclusive).
 	 * @throws IllegalArgumentException
-	 *             if <code>from</code> is greater than <code>to</code>.
+	 *             if {@code from} is greater than {@code to}.
 	 * @throws ArrayIndexOutOfBoundsException
-	 *             if <code>from</code> or <code>to</code> are greater than
-	 *             <code>bigArrayLength</code> or negative.
+	 *             if {@code from} or {@code to} are greater than
+	 *             {@code bigArrayLength} or negative.
 	 */
 	public static void ensureFromTo(final long bigArrayLength, final long from, final long to) {
 		if (from < 0) throw new ArrayIndexOutOfBoundsException("Start index (" + from + ") is negative");
@@ -258,7 +258,7 @@ public class BigArrays {
 	 * Ensures that a range given by an offset and a length fits a big array of
 	 * given length.
 	 *
-	 * <P>
+	 * <p>
 	 * This method may be used whenever a big array range check is needed.
 	 *
 	 * @param bigArrayLength
@@ -268,11 +268,11 @@ public class BigArrays {
 	 * @param length
 	 *            a length (the number of elements in the fragment).
 	 * @throws IllegalArgumentException
-	 *             if <code>length</code> is negative.
+	 *             if {@code length} is negative.
 	 * @throws ArrayIndexOutOfBoundsException
-	 *             if <code>offset</code> is negative or <code>offset</code> +
-	 *             <code>length</code> is greater than
-	 *             <code>bigArrayLength</code>.
+	 *             if {@code offset} is negative or {@code offset} +
+	 *             {@code length} is greater than
+	 *             {@code bigArrayLength}.
 	 */
 	public static void ensureOffsetLength(final long bigArrayLength, final long offset, final long length) {
 		if (offset < 0) throw new ArrayIndexOutOfBoundsException("Offset (" + offset + ") is negative");
@@ -286,7 +286,7 @@ public class BigArrays {
 	 * @param bigArrayLength
 	 *            a big-array length.
 	 * @throws IllegalArgumentException
-	 *             if <code>length</code> is negative, or larger than or equal
+	 *             if {@code length} is negative, or larger than or equal
 	 *             to {@link #SEGMENT_SIZE} * {@link Integer#MAX_VALUE}.
 	 */
 	public static void ensureLength(final long bigArrayLength) {
@@ -299,9 +299,9 @@ public class BigArrays {
 
 	/**
 	 * Transforms two consecutive sorted ranges into a single sorted range. The
-	 * initial ranges are <code>[first, middle)</code> and
-	 * <code>[middle, last)</code>, and the resulting range is
-	 * <code>[first, last)</code>. Elements in the first input range will
+	 * initial ranges are {@code [first, middle)} and
+	 * {@code [middle, last)}, and the resulting range is
+	 * {@code [first, last)}. Elements in the first input range will
 	 * precede equal elements in the second.
 	 */
 	private static void inPlaceMerge(final long from, long mid, final long to, final LongComparator comp, final BigSwapper swapper) {
@@ -349,7 +349,7 @@ public class BigArrays {
 	 * Performs a binary search on an already sorted range: finds the first
 	 * position where an element can be inserted without violating the ordering.
 	 * Sorting is by a user-supplied comparison function.
-	 * 
+	 *
 	 * @param mid
 	 *            Beginning of the range.
 	 * @param to
@@ -359,8 +359,8 @@ public class BigArrays {
 	 * @param comp
 	 *            Comparison function.
 	 * @return The largest index i such that, for every j in the range
-	 *         <code>[first, i)</code>, <code>comp.apply(array[j], x)</code> is
-	 *         <code>true</code>.
+	 *         {@code [first, i)}, {@code comp.apply(array[j], x)} is
+	 *         {@code true}.
 	 */
 	private static long lowerBound(long mid, final long to, final long firstCut, final LongComparator comp) {
 		long len = to - mid;
@@ -389,7 +389,7 @@ public class BigArrays {
 	 * Sorts the specified range of elements using the specified big swapper and
 	 * according to the order induced by the specified comparator using
 	 * mergesort.
-	 * 
+	 *
 	 * <p>
 	 * This sort is guaranteed to be <i>stable</i>: equal elements will not be
 	 * reordered as a result of the sort. The sorting algorithm is an in-place
@@ -398,7 +398,7 @@ public class BigArrays {
 	 * <i>O</i>(<var>n</var>&nbsp;(log&nbsp;<var>n</var>)<sup>2</sup>), but it
 	 * does not allocate additional memory; as a result, it can be used as a
 	 * generic sorting algorithm.
-	 * 
+	 *
 	 * @param from
 	 *            the index of the first element (inclusive) to be sorted.
 	 * @param to
@@ -440,13 +440,13 @@ public class BigArrays {
 	 * Sorts the specified range of elements using the specified big swapper and
 	 * according to the order induced by the specified comparator using
 	 * quicksort.
-	 * 
+	 *
 	 * <p>
 	 * The sorting algorithm is a tuned quicksort adapted from Jon L. Bentley
 	 * and M. Douglas McIlroy, &ldquo;Engineering a Sort Function&rdquo;,
 	 * <i>Software: Practice and Experience</i>, 23(11), pages 1249&minus;1265,
 	 * 1993.
-	 * 
+	 *
 	 * @param from
 	 *            the index of the first element (inclusive) to be sorted.
 	 * @param to
@@ -525,7 +525,7 @@ public class BigArrays {
 	 * Performs a binary search on an already-sorted range: finds the last
 	 * position where an element can be inserted without violating the ordering.
 	 * Sorting is by a user-supplied comparison function.
-	 * 
+	 *
 	 * @param from
 	 *            Beginning of the range.
 	 * @param mid
@@ -535,8 +535,8 @@ public class BigArrays {
 	 * @param comp
 	 *            Comparison function.
 	 * @return The largest index i such that, for every j in the range
-	 *         <code>[first, i)</code>, <code>comp.apply(x, array[j])</code> is
-	 *         <code>false</code>.
+	 *         {@code [first, i)}, {@code comp.apply(x, array[j])} is
+	 *         {@code false}.
 	 */
 	private static long upperBound(long from, final long mid, final long secondCut, final LongComparator comp) {
 		long len = mid - from;
