@@ -1,6 +1,6 @@
 package it.unimi.dsi.fastutil;
 
-/*		 
+/*
  * Copyright (C) 2010-2017 Sebastiano Vigna
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -13,7 +13,7 @@ package it.unimi.dsi.fastutil;
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
- * limitations under the License. 
+ * limitations under the License.
  */
 
 
@@ -22,25 +22,27 @@ import java.util.ListIterator;
 
 /** A list iterator over a {@link BigList}.
  *
- * <P>This kind of iterator is essentially a {@link ListIterator} with long indices.
+ * <p>This kind of iterator is essentially a {@link ListIterator} with long indices.
  *
  * @see Iterator
  * @see ListIterator
  */
 
 public interface BigListIterator<K> extends BidirectionalIterator<K> {
+
 	/** Returns the index of the element that would be returned by a subsequent call to next.
 	 * (Returns list size if the list iterator is at the end of the list.)
-	 * 
+	 *
 	 * @return the index of the element that would be returned by a subsequent call to next, or list
 	 * size if list iterator is at end of list.
 	 * @see ListIterator#nextIndex()
 	 */
+
 	long nextIndex();
 
 	/** Returns the index of the element that would be returned by a subsequent call to previous.
 	 * (Returns -1 if the list iterator is at the beginning of the list.)
-	 * 
+	 *
 	 * @return the index of the element that would be returned by a subsequent call to previous, or
 	 * -1 if list iterator is at beginning of list.
 	 * @see ListIterator#previousIndex()
@@ -48,15 +50,28 @@ public interface BigListIterator<K> extends BidirectionalIterator<K> {
 
 	long previousIndex();
 
-	/** Skips the given number of elements.
+	/**
+	 * Replaces the last element returned by {@link #next} or
+	 * {@link #previous} with the specified element (optional operation).
 	 *
-	 * <P>The effect of this call is exactly the same as that of
-	 * calling {@link #next()} for <code>n</code> times (possibly stopping
-	 * if {@link #hasNext()} becomes false).
+	 * <p>This default implemention just throws an {@link UnsupportedOperationException}.
 	 *
-	 * @param n the number of elements to skip.
-	 * @return the number of elements actually skipped.
+	 * @param e an element.
+	 * @see ListIterator#set(Object)
 	 */
+	default void set(K e) {
+			throw new UnsupportedOperationException();
+	}
 
-	long skip( long n );
+	/**
+	 * Inserts the specified element into the list (optional operation).
+	 *
+	 * <p>This default implemention just throws an {@link UnsupportedOperationException}.
+	 *
+	 * @param e an element.
+	 * @see ListIterator#add(Object)
+	 */
+	default void add(K e) {
+		throw new UnsupportedOperationException();
+	}
 }
