@@ -1,6 +1,6 @@
 package it.unimi.dsi.fastutil;
 
-/*		 
+/*
  * Copyright (C) 2003-2017 Sebastiano Vigna
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -13,7 +13,7 @@ package it.unimi.dsi.fastutil;
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
- * limitations under the License. 
+ * limitations under the License.
  */
 
 
@@ -31,80 +31,108 @@ public class IndirectPriorityQueues {
 
 	/** An immutable class representing the empty indirect priority queue.
 	 *
-	 * <P>This class may be useful to implement your own in case you subclass
+	 * <p>This class may be useful to implement your own in case you subclass
 	 * {@link IndirectPriorityQueue}.
 	 */
 
 	@SuppressWarnings("rawtypes")
-	public static class EmptyIndirectPriorityQueue extends AbstractIndirectPriorityQueue {
+	public static class EmptyIndirectPriorityQueue implements IndirectPriorityQueue {
 
 		protected EmptyIndirectPriorityQueue() {}
 
-		public void enqueue( final int i ) { throw new UnsupportedOperationException(); }
+		@Override
+		public void enqueue(final int i) { throw new UnsupportedOperationException(); }
+		@Override
 		public int dequeue() { throw new NoSuchElementException(); }
+		@Override
 		public boolean isEmpty() { return true; }
+		@Override
 		public int size() { return 0; }
-		public boolean contains( int index ) { return false; }
+		@Override
+		public boolean contains(int index) { return false; }
+		@Override
 		public void clear() {}
+		@Override
 		public int first() { throw new NoSuchElementException(); }
+		@Override
 		public int last() { throw new NoSuchElementException(); }
+		@Override
 		public void changed() { throw new NoSuchElementException(); }
+		@Override
 		public void allChanged() {}
+		@Override
 		public Comparator<?> comparator() { return null; }
-		public void changed( final int i ) { throw new IllegalArgumentException( "Index " + i + " is not in the queue" ); }
-		public boolean remove( final int i ) { return false; }
-		public int front( int[] a ) { return 0; }
-		
+		@Override
+		public void changed(final int i) { throw new IllegalArgumentException("Index " + i + " is not in the queue"); }
+		@Override
+		public boolean remove(final int i) { return false; }
+		@Override
+		public int front(int[] a) { return 0; }
+
 	}
 
 	/** An empty indirect priority queue (immutable).
 	 */
 
-	public final static EmptyIndirectPriorityQueue EMPTY_QUEUE = new EmptyIndirectPriorityQueue();
+	public static final EmptyIndirectPriorityQueue EMPTY_QUEUE = new EmptyIndirectPriorityQueue();
 
 
 	/** A synchronized wrapper class for indirect priority queues. */
 
 	public static class SynchronizedIndirectPriorityQueue<K> implements IndirectPriorityQueue<K> {
-		
+
 		public static final long serialVersionUID = -7046029254386353129L;
 
-		final protected IndirectPriorityQueue<K> q;
-		final protected Object sync;
+		protected final IndirectPriorityQueue<K> q;
+		protected final Object sync;
 
-		protected SynchronizedIndirectPriorityQueue( final IndirectPriorityQueue<K> q, final Object sync ) {
+		protected SynchronizedIndirectPriorityQueue(final IndirectPriorityQueue<K> q, final Object sync) {
 			this.q = q;
 			this.sync = sync;
 		}
 
-		protected SynchronizedIndirectPriorityQueue( final IndirectPriorityQueue<K> q ) {
+		protected SynchronizedIndirectPriorityQueue(final IndirectPriorityQueue<K> q) {
 			this.q = q;
 			this.sync = this;
 		}
 
-		public void enqueue( int x ) { synchronized( sync ) { q.enqueue( x ); } }
-		public int dequeue() { synchronized( sync ) { return q.dequeue(); } }
-		public boolean contains( final int index ) { synchronized( sync ) { return q.contains( index ); } }
-		public int first() { synchronized( sync ) { return q.first(); } }
-		public int last() { synchronized( sync ) { return q.last(); } }
-		public boolean isEmpty() { synchronized( sync ) { return q.isEmpty(); } }
-		public int size() { synchronized( sync ) { return q.size(); } }
-		public void clear() { synchronized( sync ) { q.clear(); } }
-		public void changed() { synchronized( sync ) { q.changed(); } }
-		public void allChanged() { synchronized( sync ) { q.allChanged(); } }
-		public void changed( int i ) { synchronized( sync ) { q.changed( i ); } }
-		public boolean remove( int i ) { synchronized( sync ) { return q.remove( i ); } }
-		public Comparator<? super K> comparator() { synchronized( sync ) { return q.comparator(); } }
-		public int front( int[] a ) { return q.front( a ); }
+		@Override
+		public void enqueue(int x) { synchronized(sync) { q.enqueue(x); } }
+		@Override
+		public int dequeue() { synchronized(sync) { return q.dequeue(); } }
+		@Override
+		public boolean contains(final int index) { synchronized(sync) { return q.contains(index); } }
+		@Override
+		public int first() { synchronized(sync) { return q.first(); } }
+		@Override
+		public int last() { synchronized(sync) { return q.last(); } }
+		@Override
+		public boolean isEmpty() { synchronized(sync) { return q.isEmpty(); } }
+		@Override
+		public int size() { synchronized(sync) { return q.size(); } }
+		@Override
+		public void clear() { synchronized(sync) { q.clear(); } }
+		@Override
+		public void changed() { synchronized(sync) { q.changed(); } }
+		@Override
+		public void allChanged() { synchronized(sync) { q.allChanged(); } }
+		@Override
+		public void changed(int i) { synchronized(sync) { q.changed(i); } }
+		@Override
+		public boolean remove(int i) { synchronized(sync) { return q.remove(i); } }
+		@Override
+		public Comparator<? super K> comparator() { synchronized(sync) { return q.comparator(); } }
+		@Override
+		public int front(int[] a) { return q.front(a); }
 	}
 
-
 	/** Returns a synchronized type-specific indirect priority queue backed by the specified type-specific indirect priority queue.
 	 *
 	 * @param q the indirect priority queue to be wrapped in a synchronized indirect priority queue.
 	 * @return a synchronized view of the specified indirect priority queue.
 	 */
-	public static <K> IndirectPriorityQueue<K> synchronize( final IndirectPriorityQueue<K> q ) {	return new SynchronizedIndirectPriorityQueue<K>( q ); }
+
+	public static <K> IndirectPriorityQueue<K> synchronize(final IndirectPriorityQueue<K> q) {	return new SynchronizedIndirectPriorityQueue<>(q); }
 
 	/** Returns a synchronized type-specific indirect priority queue backed by the specified type-specific indirect priority queue, using an assigned object to synchronize.
 	 *
@@ -113,6 +141,6 @@ public class IndirectPriorityQueues {
 	 * @return a synchronized view of the specified indirect priority queue.
 	 */
 
-	public static <K> IndirectPriorityQueue<K> synchronize( final IndirectPriorityQueue<K> q, final Object sync ) { return new SynchronizedIndirectPriorityQueue<K>( q, sync ); }
+	public static <K> IndirectPriorityQueue<K> synchronize(final IndirectPriorityQueue<K> q, final Object sync) { return new SynchronizedIndirectPriorityQueue<>(q, sync); }
 
 }
