@@ -1,6 +1,6 @@
 package it.unimi.dsi.fastutil;
 
-/*		 
+/*
  * Copyright (C) 2003-2017 Paolo Boldi and Sebastiano Vigna
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -13,7 +13,7 @@ package it.unimi.dsi.fastutil;
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
- * limitations under the License. 
+ * limitations under the License.
  */
 
 
@@ -22,16 +22,16 @@ import java.util.NoSuchElementException;
 
 /** A priority queue.
  *
- * <P>A priority queue provides a way to {@linkplain #enqueue(Object) enqueue}
+ * <p>A priority queue provides a way to {@linkplain #enqueue(Object) enqueue}
  * elements, and to {@linkplain #dequeue() dequeue} them in some specified
  * order. Elements that are <em>smaller</em> in the specified order are
  * dequeued first.  It is also possible to get the {@linkplain #first() first
  * element}, that is, the element that would be dequeued next.
  *
- * <P>Additionally, the queue may provide a method to peek at 
+ * <p>Additionally, the queue may provide a method to peek at
  * element that would be dequeued {@linkplain #last() last}.
  *
- * <P>The relative order of the elements enqueued should not change during
+ * <p>The relative order of the elements enqueued should not change during
  * queue operations. Nonetheless, some implementations may give the caller a
  * way to notify the queue that the {@linkplain #changed() first element has
  * changed its relative position in the order}.
@@ -41,10 +41,10 @@ public interface PriorityQueue<K> {
 
 	/** Enqueues a new element.
 	 *
-	 * @param x the element to enqueue..
+	 * @param x the element to enqueue.
 	 */
 
-	void enqueue( K x );
+	void enqueue(K x);
 
 	/** Dequeues the {@linkplain #first() first} element from the queue.
 	 *
@@ -54,12 +54,15 @@ public interface PriorityQueue<K> {
 
 	K dequeue();
 
-	/** Checks whether the queue is empty.
+	/** Checks whether this queue is empty.
 	 *
-	 * @return true if the queue is empty.
+	 * <P>This default implementation checks whether {@link #size()} is zero.
+	 * @return true if this queue is empty.
 	 */
 
-	boolean isEmpty();
+	default boolean isEmpty() {
+		return size() == 0;
+	}
 
 	/** Returns the number of elements in this queue.
 	 *
@@ -83,20 +86,23 @@ public interface PriorityQueue<K> {
 
 	/** Returns the last element of the queue, that is, the element the would be dequeued last (optional operation).
 	 *
+	 * <p>This default implementation just throws an {@link UnsupportedOperationException}.
 	 * @return the last element.
 	 * @throws NoSuchElementException if the queue is empty.
 	 */
 
-	K last();
+	default K last() { throw new UnsupportedOperationException(); }
 
 	/** Notifies the queue that the {@linkplain #first() first} element has changed (optional operation).
+	 * <p>This default implementation just throws an {@link UnsupportedOperationException}. 
 	 */
 
-	void changed();
+	default void changed() { throw new UnsupportedOperationException(); }
 
-    /** Returns the comparator associated with this queue, or <code>null</code> if it uses its elements' natural ordering.
+
+	/** Returns the comparator associated with this queue, or {@code null} if it uses its elements' natural ordering.
 	 *
-	 * @return the comparator associated with this sorted set, or <code>null</code> if it uses its elements' natural ordering.
+	 * @return the comparator associated with this sorted set, or {@code null} if it uses its elements' natural ordering.
 	 */
 	Comparator<? super K> comparator();
 }
