@@ -1,6 +1,6 @@
 package it.unimi.dsi.fastutil;
 
-/*		 
+/*
  * Copyright (C) 2002-2017 Sebastiano Vigna
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -13,7 +13,7 @@ package it.unimi.dsi.fastutil;
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
- * limitations under the License. 
+ * limitations under the License.
  */
 
 
@@ -21,7 +21,7 @@ import java.util.NoSuchElementException;
 
 /** A stack.
  *
- * <P>A stack must provide the classical {@link #push(Object)} and 
+ * <p>A stack must provide the classical {@link #push(Object)} and
  * {@link #pop()} operations, but may be also <em>peekable</em>
  * to some extent: it may provide just the {@link #top()} function,
  * or even a more powerful {@link #peek(int)} method that provides
@@ -36,7 +36,7 @@ public interface Stack<K> {
 	 * @param o the object that will become the new top of the stack.
 	 */
 
-	void push( K o );
+	void push(K o);
 
 	/** Pops the top off the stack.
 	 *
@@ -54,20 +54,27 @@ public interface Stack<K> {
 	boolean isEmpty();
 
 	/** Peeks at the top of the stack (optional operation).
+	 *
+	 * <p>This default implementation returns {@link #peek(int) peek(0)}.
 	 *
 	 * @return the top of the stack.
 	 * @throws NoSuchElementException if the stack is empty.
 	 */
 
-	K top();
+	default K top()  {
+		return peek(0);
+	}
 
 	/** Peeks at an element on the stack (optional operation).
+	 *
+	 * <p>This default implementation just throws an {@link UnsupportedOperationException}.
 	 *
 	 * @param i an index from the stop of the stack (0 represents the top).
-	 * @return the <code>i</code>-th element on the stack.
+	 * @return the {@code i}-th element on the stack.
 	 * @throws IndexOutOfBoundsException if the designated element does not exist..
 	 */
 
-	K peek( int i );
-
+	default K peek(int i) {
+		throw new UnsupportedOperationException();
+	}
 }
