@@ -1,25 +1,43 @@
 package it.unimi.dsi.fastutil.objects;
 
+/*
+ * Copyright (C) 2017 Sebastiano Vigna
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertSame;
 
-import it.unimi.dsi.fastutil.ints.Int2IntRBTreeMap;
 import org.junit.Test;
 
+import it.unimi.dsi.fastutil.ints.Int2IntRBTreeMap;
+
 public class ObjectRBTreeSetTest {
 
 	@Test
 	public void testGet() {
-		ObjectRBTreeSet<Integer> s = new ObjectRBTreeSet<Integer>();
-		Integer o = new Integer( 0 );
-		s.add( o );
-		assertSame( o,  s.get( new Integer( 0 ) ) );
+		final ObjectRBTreeSet<Integer> s = new ObjectRBTreeSet<>();
+		final Integer o = Integer.valueOf(0);
+		s.add(o);
+		assertSame(o,  s.get(Integer.valueOf(0)));
 	}
 
 	@Test
 	public void testAddTo() {
-		Int2IntRBTreeMap a = new Int2IntRBTreeMap();
-		Int2IntRBTreeMap b = new Int2IntRBTreeMap();
+		final Int2IntRBTreeMap a = new Int2IntRBTreeMap();
+		final Int2IntRBTreeMap b = new Int2IntRBTreeMap();
 
 		// test addTo with empty map
 		a.addTo(0, 1); 			// 0 -> 1
